'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var parseTime = exports.parseTime = function parseTime(seconds) {
  var hours = '' + Math.floor(seconds / 3600);
  var minutes = '' + Math.floor(seconds % 3600 / 60);
  var _seconds = '' + Math.floor(seconds % 3600 % 60);
  return padLeft(hours, 2) + ':' + padLeft(minutes, 2) + ':' + padLeft(_seconds, 2);
};

var padLeft = exports.padLeft = function padLeft(string, total) {
  if (typeof string !== 'string') {
    throw new Error('First parameter must be a string');
  }
  if (typeof total !== 'number') {
    throw new Error('Second parameter must be a integer');
  }
  return new Array(total - string.length + 1).join('0') + string;
};

var replaceAndTrim = exports.replaceAndTrim = function replaceAndTrim(word) {
  return word.replace(/<br\s*[/]?>/gi, '').replace(/\n/gi, '').trim();
};

var getClearWordFromTranscript = exports.getClearWordFromTranscript = function getClearWordFromTranscript(word) {
  // Wat??? If anyone figures out what the point of this replace is, can you please
  // add a note for future developers
  return replaceAndTrim(word).replace(/:$/, '');
};

var COLORS = exports.COLORS = ['#55a01a', '#9932cc', '#ff69b4', '#6495ed', '#ffd700', '#f6a7a1', '#7fb397', '#009999'];

// This method will always return the same color for a given speaker name.
var getSpeakerColor = exports.getSpeakerColor = function getSpeakerColor(speakerName) {
  var returnValue = (
  // Get the product of the binary values of the first three characters
  // of the speaker name. (Watch out for shorter speaker names...)
  speakerName.charCodeAt(0) * (speakerName.charCodeAt(1) || 1) * (speakerName.charCodeAt(2) || 1) %
  // Then get the modulus of 4095 (or the remainder of #fff)
  4095).
  // And convert to a hex representation.
  toString(16);
  return '#' + returnValue;
};

var sortByField = exports.sortByField = function sortByField(fieldName) {
  var _getFieldAndOrder = getFieldAndOrder(fieldName),
      sortOrder = _getFieldAndOrder.sortOrder,
      field = _getFieldAndOrder.field;

  return function (a, b) {
    var result = a[field] < b[field] ? -1 : a[field] > b[field] ? 1 : 0;
    return result * sortOrder;
  };
};

var getFieldAndOrder = exports.getFieldAndOrder = function getFieldAndOrder(field) {
  var sortOrder = 1;
  if (field[0] === '-') {
    sortOrder = -1;
    field = field.substr(1);
  }
  return { sortOrder: sortOrder, field: field };
};

var parseMediaType = exports.parseMediaType = function parseMediaType(type) {
  if (type.indexOf('audio') > -1) {
    return 'audio';
  } else if (type.indexOf('video') > -1) {
    return 'video';
  } else return type;
};