'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.searchResultsToMarkers = exports.replaceAndTrim = exports.parseTerms = exports.searchStringToTerms = exports.createEngine = exports.searchWords = exports.splitPhrase = exports.searchPhrases = exports.localSearch = undefined;

var _fuse = require('fuse.js');

var _fuse2 = _interopRequireDefault(_fuse);

var _Common = require('./Common');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var localSearch = exports.localSearch = function localSearch(transcript, searchString) {
  console.time('localSearch');
  // Transform the transcript into an array for usage with fuse.js
  var transcriptArray = Object.keys(transcript).reduce(function (transcriptArray, key) {
    transcriptArray.push(transcript[key]);
    return transcriptArray;
  }, []);
  var fuseEngine = createEngine(transcriptArray, ['w']);
  var terms = searchStringToTerms(searchString);

  var _parseTerms = parseTerms(terms),
      phrases = _parseTerms.phrases,
      words = _parseTerms.words;

  var wordsResult = searchWords(words, fuseEngine);
  var phrasesResult = searchPhrases(transcriptArray, phrases, fuseEngine);

  console.timeEnd('localSearch');
  return Object.assign({}, wordsResult, phrasesResult);
};

var searchPhrases = exports.searchPhrases = function searchPhrases(transcript, phrases, fuseEngine) {
  console.time('indexOf');
  var result = {};

  phrases.forEach(function (phrase) {
    var innerWords = splitPhrase(phrase);
    var wordsCount = innerWords.length;
    phrase = innerWords.join(' ');

    if (wordsCount > 0) {
      var firstWordResult = fuseEngine.search(innerWords[0]);
      firstWordResult.forEach(function (resItem) {
        var num = resItem.p;
        var tempPhrase = '';

        for (var i = 0; i < wordsCount; i++) {
          var nextWord = transcript[num];
          if (!nextWord) break;

          var space = i !== 0 ? ' ' : '';
          if (nextWord.m === 'punc') {
            space = '';
            i--;
          }

          tempPhrase += space + replaceAndTrim(nextWord.w).toLowerCase();

          var partOfPhrase = innerWords.slice(0, i + 1);
          partOfPhrase = partOfPhrase.join(' ');
          if (partOfPhrase !== tempPhrase.trim() && transcript[num + 1] && transcript[num + 1].m !== 'punc') {
            break;
          }
          num++;
        }

        var isMatch = tempPhrase.indexOf(phrase) !== -1;
        if (isMatch) {
          if (!result[phrase]) {
            result[phrase] = [];
          }
          result[phrase].push({
            time: resItem.s / 1000,
            keywordName: phrase
          });
        }
      });
    }
  });

  console.timeEnd('indexOf');
  return result;
};

var splitPhrase = exports.splitPhrase = function splitPhrase(phrase) {
  phrase = phrase.toLocaleLowerCase().replace(/"/g, '');
  phrase = replaceAndTrim(phrase);
  var phraseWords = phrase.split(/(?=\W)(?=\s)/);
  var innerWords = [];
  phraseWords.forEach(function (word) {
    word = replaceAndTrim(word);
    if (word !== '') {
      innerWords.push(word);
    }
  });
  return innerWords;
};

var searchWords = exports.searchWords = function searchWords(words, fuseEngine) {
  console.time('fuse');
  var result = {};

  words.forEach(function (word) {
    var res = fuseEngine.search(word);
    res = res.map(function (resItem) {
      return {
        time: resItem.s / 1000,
        keywordName: resItem.w
      };
    });
    result[word] = res;
  });

  console.timeEnd('fuse');
  return result;
};

var createEngine = exports.createEngine = function createEngine(transcript, keys) {
  return new _fuse2.default(transcript, {
    keys: keys,
    threshold: 0.2
  });
};

var searchStringToTerms = exports.searchStringToTerms = function searchStringToTerms(searchString) {
  return searchString.match(/("[^"]+")+|[\S]+/ig);
};

var parseTerms = exports.parseTerms = function parseTerms(terms) {
  var phrases = [];
  var words = [];

  terms.forEach(function (term) {
    if (term.indexOf('"') === 0 && term.lastIndexOf('"') === term.length - 1) {
      // if "many words"
      phrases.push(term);
    } else {
      words.push(term);
    }
  });

  return { phrases: phrases, words: words };
};

var replaceAndTrim = exports.replaceAndTrim = function replaceAndTrim(word) {
  return word.replace(/<br\s*[/]?>/gi, '').replace(/\n/gi, '').trim();
};

var searchResultsToMarkers = exports.searchResultsToMarkers = function searchResultsToMarkers(searchResults) {
  var results = [];
  Object.keys(searchResults).forEach(function (term, i) {
    var color = _Common.COLORS[i] ? _Common.COLORS[i] : (0, _Common.getRandomColor)();
    var markers = searchResults[term].map(function (item) {
      return Object.assign({}, item, { color: color });
    });
    results = results.concat(markers);
  });
  return results;
};