'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.shallowRender = exports.checkApiAction = exports.checkCreatingActionWithMultipleParameters = exports.checkCreatingAction = exports.checkType = exports.checkIsFunction = exports.checkActionTypes = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _reduxActions = require('redux-actions');

var _reduxMockStore = require('redux-mock-store');

var _reduxMockStore2 = _interopRequireDefault(_reduxMockStore);

var _reduxPromiseMiddleware = require('redux-promise-middleware');

var _reduxPromiseMiddleware2 = _interopRequireDefault(_reduxPromiseMiddleware);

var _reduxThunk = require('redux-thunk');

var _reduxThunk2 = _interopRequireDefault(_reduxThunk);

var _testUtils = require('react-dom/test-utils');

var _testUtils2 = _interopRequireDefault(_testUtils);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

/*
* ACTIONS TESTING
* */
var checkActionTypes = exports.checkActionTypes = function checkActionTypes(actions, actionName, actionType) {
  checkIsFunction(actions, actionName);
  checkType(actions, actionType, actionName);
};

var checkIsFunction = exports.checkIsFunction = function checkIsFunction(actions, actionName) {
  it('Should be exported ' + actionName + ' action as a function.', function () {
    expect(actions[actionName]).to.be.a('function');
  });
};

var checkType = exports.checkType = function checkType(actions, actionType, actionName) {
  it('Should return an action with type "' + actionType + '"', function () {
    expect(actions[actionName]()).to.have.property('type', actionType);
  });
};

var checkCreatingAction = exports.checkCreatingAction = function checkCreatingAction(actions, actionName, actionType, props) {
  var _this = this;

  it('Should create an action to ' + actionName, function () {
    var expectedAction = (0, _reduxActions.createAction)(actionType);
    expect(actions[actionName].apply(_this, props)).to.deep.equal(expectedAction.apply(_this, props));
  });
};

var checkCreatingActionWithMultipleParameters = exports.checkCreatingActionWithMultipleParameters = function checkCreatingActionWithMultipleParameters(actions, actionName, actionType, props, propNames) {
  var _this2 = this;

  it('Should create an action to ' + actionName, function () {
    var expectedAction = _reduxActions.createAction.apply(_this2, [actionType, function () {
      var params = {};
      propNames.forEach(function (name, i) {
        params[name] = props[i];
      });
      return params;
    }]);
    expect(actions[actionName].apply(_this2, props)).to.deep.equal(expectedAction.apply(_this2, props));
  });
};

/*
actions: object of action creators, key: string, value: function
actionName: name of the action creator being tested, string like 'getDataForMedia'
actionType: the expected action type value, eg. GET_DATA_FOR_MEDIA
params: argumens for action creator, array like ['token', 'mediaId', '']
allowedErrorMessage: false for no response errors allowed, otherwise a text included in allowed error messages
*/
var checkApiAction = exports.checkApiAction = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(actions, actionName, actionType, params, allowedErrorMessage) {
    var PENDING, REJECTED, FULFILLED, requests, store, TYPE_PENDING, dispatchResult, storeActions, action, TYPE, e, result, action2, message, reasonError;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            PENDING = '_PENDING'; // TODO remove on redux-promise-middleware 4+

            REJECTED = '_REJECTED'; // TODO remove on redux-promise-middleware 4+

            FULFILLED = '_FULFILLED'; // TODO remove on redux-promise-middleware 4+

            requests = [];

            sinon.useFakeXMLHttpRequest().onCreate = function (xhr) {
              return requests.push(xhr);
            };

            store = (0, _reduxMockStore2.default)([_reduxThunk2.default, (0, _reduxPromiseMiddleware2.default)()])(); // empty Redux store instance

            // dispatch of the created action should trigger middleware to submit a PENDING action

            TYPE_PENDING = actionType + PENDING;
            dispatchResult = store.dispatch(actions[actionName].apply(null, params));
            _context.next = 10;
            return Promise.resolve();

          case 10:
            // allow middleware to submit the server request
            expect(dispatchResult && _typeof(dispatchResult.then), 'dispatch result is promise').to.equal('function'); // instanceof Prom,ise no work
            storeActions = store.getActions();

            expect(storeActions.length, 'dispatch count').to.equal(1);
            action = storeActions[0];

            expect(action.type).to.equal(TYPE_PENDING);
            expect(requests.length, 'request count').to.equal(1);

            // server response should trigger middleware to submit a final action
            TYPE = actionType + (allowedErrorMessage ? REJECTED : FULFILLED);

            requests[0].respond(allowedErrorMessage ? 500 : 200);
            e = void 0;
            _context.next = 21;
            return dispatchResult.catch(function (ee) {
              return e = ee;
            });

          case 21:
            result = _context.sent;
            // allow middleware to finish, store error in err
            storeActions = store.getActions();
            expect(storeActions.length, 'dispatch count').to.equal(2);
            action2 = storeActions[1];

            expect(action2.type).to.equal(TYPE);

            if (!e) {
              _context.next = 36;
              break;
            }

            // verify error message
            // e is Error with properties: reason action line sourceURL stack
            // e.reason.error may be Error with properties: config response
            message = [];

            if (e.message) message.push('Error message:\' ' + e.message); // e is Error, so e.message is string
            reasonError = e.reason && e.reason.error instanceof Error && e.reason.error;

            if (reasonError && reasonError.message) message.push('Reason: ' + reasonError.message);
            message = message.join('\n');
            if (!message) message = 'Error without message';

            // if error message contains a possible allowedErrorMessage string, ignore it

            if (!(!allowedErrorMessage || !~message.indexOf(allowedErrorMessage))) {
              _context.next = 36;
              break;
            }

            console.error('checkApiAction: upcoming failure:', message); // make sure the error
            throw e;

          case 36:
            return _context.abrupt('return', result);

          case 37:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  }));

  return function checkApiAction(_x, _x2, _x3, _x4, _x5) {
    return _ref.apply(this, arguments);
  };
}();

/*
 * COMPONENTS TESTING
 * */
var shallowRender = exports.shallowRender = function shallowRender(component) {
  var renderer = _testUtils2.default.createRenderer();
  renderer.render(component);
  return renderer.getRenderOutput();
};