'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.actions = exports.choosePlayerAppTab = exports.setActiveTopic = exports.removeMediaData = exports.setAnalytics = exports.setMediaUrl = exports.initialState = exports.initialViewState = exports.GROUPS_TAB = exports.CLASSIFIER_TAB = exports.DETECTION_TAB = exports.KEYWORDS_TAB = exports.CHOOSE_PLAYER_APP_TAB = exports.SET_ACTIVE_TOPIC = exports.REMOVE_MEDIA_DATA = exports.SET_ANALYTICS = exports.SET_MEDIA_URL = undefined;

var _handleActions;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _reduxActions = require('redux-actions');

var _immutable = require('immutable');

var Immutable = _interopRequireWildcard(_immutable);

var _analyticsParser = require('../../utilities/analytics-parser');

var _analyticsParser2 = _interopRequireDefault(_analyticsParser);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
 * Constants
 * */
var SET_MEDIA_URL = exports.SET_MEDIA_URL = 'SET_MEDIA_URL';
var SET_ANALYTICS = exports.SET_ANALYTICS = 'SET_ANALYTICS';
var REMOVE_MEDIA_DATA = exports.REMOVE_MEDIA_DATA = 'REMOVE_MEDIA_DATA';
var SET_ACTIVE_TOPIC = exports.SET_ACTIVE_TOPIC = 'SET_ACTIVE_TOPIC';
var CHOOSE_PLAYER_APP_TAB = exports.CHOOSE_PLAYER_APP_TAB = 'CHOOSE_PLAYER_APP_TAB';

var KEYWORDS_TAB = exports.KEYWORDS_TAB = 1;
var DETECTION_TAB = exports.DETECTION_TAB = 2;
var CLASSIFIER_TAB = exports.CLASSIFIER_TAB = 3;
var GROUPS_TAB = exports.GROUPS_TAB = 4;

/**
 * State
 */
var initialViewState = exports.initialViewState = {
  activeTab: KEYWORDS_TAB
};

var initialState = exports.initialState = new Immutable.Map({
  // TODO: Analytics should be stored together, not at the root level.
  analyticsLoaded: false,
  metadata: new Immutable.Map(),
  topicsIds: new Immutable.List(),
  topics: new Immutable.Map(),
  activeTopic: '',
  groupsIds: new Immutable.List(),
  groups: new Immutable.Map(),
  activeGroup: '',
  speakers: new Immutable.Map(),
  transcriptSpeakers: new Immutable.Map(),
  activeSpeaker: '',
  transcript: new Immutable.List(),
  classifiers: [],
  detectors: [],
  jobTasks: new Immutable.Map(),
  mediaUrlLoaded: false,
  mediaUrl: '',
  // TODO: Not sure why there is view data in here when
  // there is a player slice that handles this type of data?
  view: initialViewState
});

/**
 * Actions
 */
var setMediaUrl = exports.setMediaUrl = (0, _reduxActions.createAction)(SET_MEDIA_URL, function (mediaUrl) {
  return { mediaUrl: mediaUrl };
});

var setAnalytics = exports.setAnalytics = function setAnalytics(schemaVersion, rawAnalytics) {
  var analytics = (0, _analyticsParser2.default)(schemaVersion, rawAnalytics);
  return function (dispatch) {
    dispatch({
      type: SET_ANALYTICS,
      payload: { analytics: analytics }
    });
  };
};

var removeMediaData = exports.removeMediaData = (0, _reduxActions.createAction)(REMOVE_MEDIA_DATA);

var setActiveTopic = exports.setActiveTopic = (0, _reduxActions.createAction)(SET_ACTIVE_TOPIC, function (topicId, type) {
  return { topicId: topicId, type: type };
});

var choosePlayerAppTab = exports.choosePlayerAppTab = (0, _reduxActions.createAction)(CHOOSE_PLAYER_APP_TAB, function (tabId) {
  return { tabId: tabId };
});

var actions = exports.actions = {
  setMediaUrl: setMediaUrl,
  setAnalytics: setAnalytics,
  removeMediaData: removeMediaData,
  setActiveTopic: setActiveTopic,
  choosePlayerAppTab: choosePlayerAppTab
};

/**
 * Reducers
 */
exports.default = (0, _reduxActions.handleActions)((_handleActions = {}, _defineProperty(_handleActions, SET_MEDIA_URL, function (state, _ref) {
  var mediaUrl = _ref.payload.mediaUrl;
  return state.merge({
    mediaUrl: mediaUrl,
    mediaUrlLoaded: true
  });
}), _defineProperty(_handleActions, SET_ANALYTICS, function (state, _ref2) {
  var analytics = _ref2.payload.analytics;
  return state.merge(_extends({}, analytics, {
    analyticsLoaded: true,
    view: initialViewState
  }));
}), _defineProperty(_handleActions, REMOVE_MEDIA_DATA, function () {
  return initialState;
}), _defineProperty(_handleActions, SET_ACTIVE_TOPIC, function (state, _ref3) {
  var _ref3$payload = _ref3.payload,
      topicId = _ref3$payload.topicId,
      type = _ref3$payload.type;

  var field = type === 'keywords' ? 'activeTopic' : 'activeGroup';
  return state.set(field, topicId);
}), _defineProperty(_handleActions, CHOOSE_PLAYER_APP_TAB, function (state, _ref4) {
  var tabId = _ref4.payload.tabId;
  return state.setIn(['view', 'activeTab'], tabId);
}), _handleActions), initialState);