'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initialState = exports.initialPlayerState = exports.actions = exports.setFullscreen = exports.clearUtteranceTime = exports.setUtteranceTime = exports.setTimelineWidth = exports.setDuration = exports.setBuffered = exports.setPosition = exports.pause = exports.play = exports.destroyPlayer = exports.createPlayer = exports.SET_FULLSCREEN = exports.CLEAR_UTTERANCE_TIME = exports.SET_UTTERANCE_TIME = exports.SET_TIMELINE_WIDTH = exports.SET_DURATION = exports.SET_BUFFERED = exports.SET_POSITION = exports.PAUSE = exports.PLAY = exports.DESTROY_PLAYER = exports.CREATE_PLAYER = undefined;

var _handleActions;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _reduxActions = require('redux-actions');

var _immutable = require('immutable');

var Immutable = _interopRequireWildcard(_immutable);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
 * Constants
 * */
var CREATE_PLAYER = exports.CREATE_PLAYER = 'CREATE_PLAYER';
var DESTROY_PLAYER = exports.DESTROY_PLAYER = 'DESTROY_PLAYER';
var PLAY = exports.PLAY = 'PLAY';
var PAUSE = exports.PAUSE = 'PAUSE';
var SET_POSITION = exports.SET_POSITION = 'SET_POSITION';
var SET_BUFFERED = exports.SET_BUFFERED = 'SET_BUFFERED';
var SET_DURATION = exports.SET_DURATION = 'SET_DURATION';
var SET_TIMELINE_WIDTH = exports.SET_TIMELINE_WIDTH = 'SET_TIMELINE_WIDTH';
var SET_UTTERANCE_TIME = exports.SET_UTTERANCE_TIME = 'SET_UTTERANCE_TIME';
var CLEAR_UTTERANCE_TIME = exports.CLEAR_UTTERANCE_TIME = 'CLEAR_UTTERANCE_TIME';
var SET_FULLSCREEN = exports.SET_FULLSCREEN = 'SET_FULLSCREEN';

/*
 * Actions
 * */
var createPlayer = exports.createPlayer = (0, _reduxActions.createAction)(CREATE_PLAYER, function (url, type) {
  return { url: url, type: type };
});
var destroyPlayer = exports.destroyPlayer = (0, _reduxActions.createAction)(DESTROY_PLAYER);
var play = exports.play = (0, _reduxActions.createAction)(PLAY);
var pause = exports.pause = (0, _reduxActions.createAction)(PAUSE);
var setPosition = exports.setPosition = (0, _reduxActions.createAction)(SET_POSITION, function (pos) {
  return pos;
});
var setBuffered = exports.setBuffered = (0, _reduxActions.createAction)(SET_BUFFERED, function (pos) {
  return pos;
});
var setDuration = exports.setDuration = (0, _reduxActions.createAction)(SET_DURATION, function (duration) {
  return duration;
});
var setTimelineWidth = exports.setTimelineWidth = (0, _reduxActions.createAction)(SET_TIMELINE_WIDTH, function (timelineWidth) {
  return timelineWidth;
});
var setUtteranceTime = exports.setUtteranceTime = (0, _reduxActions.createAction)(SET_UTTERANCE_TIME, function (time) {
  return time;
});
var clearUtteranceTime = exports.clearUtteranceTime = (0, _reduxActions.createAction)(CLEAR_UTTERANCE_TIME);
var setFullscreen = exports.setFullscreen = (0, _reduxActions.createAction)(SET_FULLSCREEN, function (isFullscreen) {
  return isFullscreen;
});

var actions = exports.actions = {
  createPlayer: createPlayer,
  destroyPlayer: destroyPlayer,
  play: play,
  pause: pause,
  setPosition: setPosition,
  setBuffered: setBuffered,
  setDuration: setDuration,
  setTimelineWidth: setTimelineWidth,
  setUtteranceTime: setUtteranceTime,
  clearUtteranceTime: clearUtteranceTime,
  setFullscreen: setFullscreen
};

/*
 * State
 * */
var initialPlayerState = exports.initialPlayerState = {
  url: '',
  type: 'audio',
  playing: false,
  played: 0,
  loaded: 0,
  duration: 0,
  timelineWidth: null,
  utteranceTime: null,
  isFullscreen: false,
  error: ''
};

var initialState = exports.initialState = new Immutable.Map(initialPlayerState);

/*
 * Reducers
 * */
exports.default = (0, _reduxActions.handleActions)((_handleActions = {}, _defineProperty(_handleActions, CREATE_PLAYER, function (state, _ref) {
  var payload = _ref.payload;

  return state.merge(_extends({}, initialPlayerState, {
    url: payload.url,
    type: payload.type
  }));
}), _defineProperty(_handleActions, DESTROY_PLAYER, function (state) {
  return state.merge(_extends({}, initialPlayerState));
}), _defineProperty(_handleActions, PLAY, function (state) {
  return state.set('playing', true);
}), _defineProperty(_handleActions, PAUSE, function (state) {
  return state.set('playing', false);
}), _defineProperty(_handleActions, SET_POSITION, function (state, _ref2) {
  var pos = _ref2.payload;

  return state.set('played', pos);
}), _defineProperty(_handleActions, SET_BUFFERED, function (state, _ref3) {
  var pos = _ref3.payload;

  return state.set('loaded', pos);
}), _defineProperty(_handleActions, SET_DURATION, function (state, _ref4) {
  var duration = _ref4.payload;

  return state.set('duration', duration);
}), _defineProperty(_handleActions, SET_TIMELINE_WIDTH, function (state, _ref5) {
  var timelineWidth = _ref5.payload;

  return state.set('timelineWidth', timelineWidth);
}), _defineProperty(_handleActions, SET_UTTERANCE_TIME, function (state, _ref6) {
  var time = _ref6.payload;

  return state.set('utteranceTime', time);
}), _defineProperty(_handleActions, CLEAR_UTTERANCE_TIME, function (state) {
  return state.set('utteranceTime', null);
}), _defineProperty(_handleActions, SET_FULLSCREEN, function (state, _ref7) {
  var isFullscreen = _ref7.payload;

  return state.set('isFullscreen', isFullscreen);
}), _handleActions), initialState);