'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utility = require('./utility');

var parse = function parse(dataOriginal) {
  // At the moment, we expect the schema of a call to match the returned schema of a /media/${id}
  // call which looks like {_links: {}, media: {}}. The following code is legacy expecting just
  // the media property so we break it out here.

  var data = dataOriginal.media;

  var topics = [];
  var groups = [];
  var speakers = [];
  var transcript = [];
  var transcriptSpeakers = [];

  if (data.keywords && data.keywords.latest && data.keywords.latest.words) {
    var _parseKeywordsArray = (0, _utility.parseKeywordsArray)(data.keywords.latest.words),
        keywords = _parseKeywordsArray.keywords,
        keywordSpeakers = _parseKeywordsArray.speakers;

    topics.push({
      name: 'ALL TOPICS',
      type: 'category',
      keywords: keywords,
      speakers: keywordSpeakers
    });
    speakers = (0, _utility.addSpeakersToSpeakerArray)(speakers, keywordSpeakers);
  }

  if (data.keywords && data.keywords.latest && data.keywords.latest.groups) {
    var _parseTopicsArray = (0, _utility.parseTopicsArray)(data.keywords.latest.groups),
        groupsArrayTopics = _parseTopicsArray.topics,
        groupsArraySpeakers = _parseTopicsArray.speakers;

    groups = groups.concat(groupsArrayTopics);
    speakers = (0, _utility.addSpeakersToSpeakerArray)(speakers, groupsArraySpeakers);
  }

  if (data.topics && data.topics.latest && data.topics.latest.topics) {
    var _parseTopicsArray2 = (0, _utility.parseTopicsArray)(data.topics.latest.topics),
        topicsArrayTopics = _parseTopicsArray2.topics,
        topicsArraySpeakers = _parseTopicsArray2.speakers;

    topics = topics.concat(topicsArrayTopics);
    speakers = (0, _utility.addSpeakersToSpeakerArray)(speakers, topicsArraySpeakers);
  }

  if (data.transcripts && data.transcripts.latest && data.transcripts.latest.words) {
    var _parseWordsArray = (0, _utility.parseWordsArray)(data.transcripts.latest.words),
        wordsArrayWords = _parseWordsArray.words,
        wordsArraySpeakers = _parseWordsArray.speakers,
        wordsArrayTranscriptSpeakers = _parseWordsArray.transcriptSpeakers;

    transcript = transcript.concat(wordsArrayWords);
    speakers = (0, _utility.addSpeakersToSpeakerArray)(speakers, wordsArraySpeakers);
    transcriptSpeakers = wordsArrayTranscriptSpeakers;
  }

  /**
   * Predictions supposedly have never worked on the v2 player. Taking this out for now.
   *
   * It appears as though it is still built around v1 spec?? It looks for a name property
   * on a prediction object but this property does not exist.
   */

  // let predictions = null;
  // if (data.predictions && data.predictions.latest && data.predictions.latest.predictions) {
  //   predictions = parsePredictionsArray(data.predictions.latest.predictions);
  // }
  //
  // let utterances = null;
  // if (data.utterances && data.utterances.latest && data.utterances.latest.utterances) {
  //   let result = normalize(data.utterances.latest.utterances, (utterance, i) => {
  //     return {
  //       ...utterance,
  //       id: i.toString(),
  //       color: getRandomColor(),
  //     };
  //   });
  //   utterances = {
  //     itemIds: result.ids,
  //     items: result.entities,
  //   };
  // }

  var returnObject = {
    activeTopic: 0,
    topics: topics,
    activeGroup: 0,
    groups: groups,
    activeSpeaker: 0,
    speakers: speakers,
    transcriptSpeakers: transcriptSpeakers,
    transcript: transcript,
    predictions: null,
    utterances: null
  };

  // console.log(JSON.stringify(returnObject));
  return returnObject;
};

exports.default = parse;