'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utility = require('./utility');

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var parseKeywords = function parseKeywords(keywords) {
  return keywords.filter(function (k) {
    return k.mentions;
  }).map(function (k) {
    return {
      name: k.keyword,
      score: !isNaN(k.relevance) ? k.relevance : 1,
      t: k.mentions.map(function (m) {
        return _defineProperty({}, m.speakerName, m.occurrences.map(function (o) {
          return o.s * 0.001;
        }));
      }).reduce(function (acc, m) {
        return Object.assign(acc, m);
      }, {}),
      internalName: []
    };
  });
};

var parseUniqueSpeakersFromKeywords = function parseUniqueSpeakersFromKeywords(keywords) {
  return [].concat(_toConsumableArray(keywords.filter(function (k) {
    return k.mentions;
  }).map(function (k) {
    return k.mentions.map(function (m) {
      return m.speakerName;
    });
  }).reduce(function (acc, s) {
    return acc.concat(s);
  }, []).reduce(function (acc, s) {
    return acc.add(s);
  }, new Set())));
};

var parse = function parse(data) {
  var topics = [];
  var groups = [];
  var speakers = [];
  var transcript = [];
  var transcriptSpeakers = [];

  if (data.spotting) {
    if (data.spotting.groups) {
      groups = groups.concat(data.spotting.groups.map(function (g) {
        return {
          name: g.groupName,
          keywords: parseKeywords(g.spottedKeywords),
          speakers: parseUniqueSpeakersFromKeywords(g.spottedKeywords),
          score: 1,
          similarCategories: [],
          subcategories: [],
          type: 'category'
        };
      }));
    }
  }

  if (data.knowledge) {
    if (data.knowledge.keywords) {
      topics.push({
        name: 'ALL TOPICS',
        type: 'category',
        keywords: parseKeywords(data.knowledge.keywords),
        speakers: parseUniqueSpeakersFromKeywords(data.knowledge.keywords)
      });
    }

    if (data.knowledge.topics) {
      topics = topics.concat(data.knowledge.topics.map(function (t) {
        return {
          name: t.topicName,
          keywords: parseKeywords(t.keywords),
          speakers: parseUniqueSpeakersFromKeywords(t.keywords),
          score: t.relevance,
          similarCategories: [],
          subcategories: [],
          type: 'category'
        };
      }));
    }
  }

  if (data.transcript && data.transcript.words) {
    var _parseWordsArray = (0, _utility.parseWordsArray)(data.transcript.words),
        wordsArrayWords = _parseWordsArray.words,
        wordsArraySpeakers = _parseWordsArray.speakers,
        wordsArrayTranscriptSpeakers = _parseWordsArray.transcriptSpeakers;

    transcript = transcript.concat(wordsArrayWords);
    speakers = (0, _utility.addSpeakersToSpeakerArray)(speakers, wordsArraySpeakers);
    transcriptSpeakers = wordsArrayTranscriptSpeakers;
  }

  var returnObject = {
    activeTopic: 0,
    topics: topics,
    activeGroup: 0,
    groups: groups,
    activeSpeaker: 0,
    speakers: speakers,
    transcriptSpeakers: transcriptSpeakers,
    transcript: transcript,
    predictions: null,
    utterances: null
  };

  return returnObject;
};

exports.default = parse;