'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AVAILABLE_ANALYTICS_SCHEMAS = exports.ANALYTICS_SCHEMA_VERSION_EVENT_STREAM = exports.ANALYTICS_SCHEMA_VERSION_V3 = exports.ANALYTICS_SCHEMA_VERSION_V2_CALLBACK = exports.ANALYTICS_SCHEMA_VERSION_V2 = undefined;

var _v = require('./v2');

var _v2 = _interopRequireDefault(_v);

var _v2Callback = require('./v2-callback');

var _v2Callback2 = _interopRequireDefault(_v2Callback);

var _v3 = require('./v3');

var _v4 = _interopRequireDefault(_v3);

var _eventStream = require('./event-stream');

var _eventStream2 = _interopRequireDefault(_eventStream);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ANALYTICS_SCHEMA_VERSION_V2 = exports.ANALYTICS_SCHEMA_VERSION_V2 = 'ANALYTICS_SCHEMA_VERSION_V2';
var ANALYTICS_SCHEMA_VERSION_V2_CALLBACK = exports.ANALYTICS_SCHEMA_VERSION_V2_CALLBACK = 'ANALYTICS_SCHEMA_VERSION_V2_CALLBACK';
var ANALYTICS_SCHEMA_VERSION_V3 = exports.ANALYTICS_SCHEMA_VERSION_V3 = 'ANALYTICS_SCHEMA_VERSION_V3';
var ANALYTICS_SCHEMA_VERSION_EVENT_STREAM = exports.ANALYTICS_SCHEMA_VERSION_EVENT_STREAM = 'ANALYTICS_SCHEMA_VERSION_EVENT_STREAM';
var AVAILABLE_ANALYTICS_SCHEMAS = exports.AVAILABLE_ANALYTICS_SCHEMAS = [ANALYTICS_SCHEMA_VERSION_V2, ANALYTICS_SCHEMA_VERSION_V2_CALLBACK, ANALYTICS_SCHEMA_VERSION_V3, ANALYTICS_SCHEMA_VERSION_EVENT_STREAM];

var analyticsParser = function analyticsParser(schemaVersion, data) {
  var implementedSchemaVersions = [ANALYTICS_SCHEMA_VERSION_V2, ANALYTICS_SCHEMA_VERSION_V2_CALLBACK, ANALYTICS_SCHEMA_VERSION_EVENT_STREAM, ANALYTICS_SCHEMA_VERSION_V3];

  if (!implementedSchemaVersions.includes(schemaVersion)) {
    var error = 'The given schemaVersion of \'' + schemaVersion + '\' is not implemented.\n      Valid versions are ' + implementedSchemaVersions.join(', ');
    throw new Error(error);
  }

  var parsedData = void 0;
  switch (schemaVersion) {
    case ANALYTICS_SCHEMA_VERSION_V2:
      parsedData = (0, _v2.default)(data);
      break;
    case ANALYTICS_SCHEMA_VERSION_V2_CALLBACK:
      parsedData = (0, _v2Callback2.default)(data);
      break;
    case ANALYTICS_SCHEMA_VERSION_V3:
      parsedData = (0, _v4.default)(data);
      break;
    case ANALYTICS_SCHEMA_VERSION_EVENT_STREAM:
      parsedData = (0, _eventStream2.default)(data);
      break;
    default:
      // We shouldn't be able to get here. We already have an implemented schema check prior.
      break;
  }

  return parsedData;
};

exports.default = analyticsParser;