'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var identifySearchTermRangesInSearchWordLibrary = exports.identifySearchTermRangesInSearchWordLibrary = function identifySearchTermRangesInSearchWordLibrary(searchTerm, searchWordLibrary) {
  var fullText = searchWordLibrary.fullText,
      wordIndexByCharacterPosition = searchWordLibrary.wordIndexByCharacterPosition,
      words = searchWordLibrary.words;

  var fullTextRegex = void 0;
  try {
    fullTextRegex = new RegExp(searchTerm, 'ig');
  } catch (error) {
    // Regex failed, continue without completing the search
    return [];
  }

  // Get all the matches by regex
  var foundCharacterRanges = [];
  var result = fullTextRegex.exec(fullText);
  while (result) {
    foundCharacterRanges.push([result.index, fullTextRegex.lastIndex]);
    result = fullTextRegex.exec(fullText);
  }

  return foundCharacterRanges.map(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        startCharacter = _ref2[0],
        endCharacter = _ref2[1];

    var startWord = null;
    var startTime = null;
    var endWord = null;
    var endTime = null;
    var currentWordIndex = 0;
    do {
      var currentCharacterIndex = wordIndexByCharacterPosition[currentWordIndex];
      if (!startTime && startCharacter < currentCharacterIndex) {
        // Why Minus 1? Because we know that the startCharacter is below the current
        // character index which means that it was the previous word.
        startWord = words[currentWordIndex - 1];
        startTime = startWord.s; // NOTE: start time
      }
      if (!endTime && endCharacter <= currentCharacterIndex) {
        // Why Minus 1? Because we know that the endCharacter is below the current
        // character index which means that it was the previous word.
        // We also make this if a less than or equal so that a space at the end of a
        // search string doesn't highlight the next word.
        endWord = words[currentWordIndex - 1];
        endTime = endWord.e; // NOTE: end time
      }
      currentWordIndex += 1;
    } while ((!startTime || !endTime) && currentWordIndex < wordIndexByCharacterPosition.length);

    return {
      startTime: startTime,
      endTime: endTime,
      // Currently including startWord and endWord but only for debug purposes.
      // Other use cases may not return these values.
      startWord: startWord,
      endWord: endWord
    };
  });
};

var createSearchWordLibraryFromWordsArray = exports.createSearchWordLibraryFromWordsArray = function createSearchWordLibraryFromWordsArray(wordsArray) {
  return wordsArray
  // If this word is a meta object, remove it, we only care about words.
  .filter(function (word) {
    return !word.m;
  }).reduce(function (info, word) {
    // Get the word position of this word, being the last index of the word index
    var wordPosition = info.wordIndexByCharacterPosition.length - 1;
    // Get the characterPosition of this word, which is the last value in the lookup array.
    var characterPosition = info.wordIndexByCharacterPosition[wordPosition];
    return {
      // Append this word to the fullText which we use to search
      fullText: info.fullText ? info.fullText + ' ' + word.w : word.w,
      // Add the position of the next word by adding the character position of this word and
      // its length to get the start position of the next word (plus one for the space!).
      wordIndexByCharacterPosition: info.wordIndexByCharacterPosition.concat(characterPosition + word.w.length + 1),
      // Create our own words array which does not include metadata objects.
      words: info.words.concat(word)
    };
  }, {
    fullText: '',
    wordIndexByCharacterPosition: [0],
    words: []
  });
};